@@ -221,17 +221,23 @@ impl<'a, 'b> Matcher<'a, 'b> {
     pub fn compgen(&self) -> Vec<(String, String)> {
         match &self.arg_comp {
             ArgComp::FlagOrOption => self.comp_flag_options(),
-            ArgComp::FlagOrOptionCombine(value) => self
-                .comp_flag_options()
-                .iter()
-                .filter_map(|(x, y)| {
-                    if x.len() == 2 {
-                        Some((format!("{value}{}", &x[1..]), y.to_string()))
-                    } else {
-                        None
-                    }
-                })
-                .collect(),
+            ArgComp::FlagOrOptionCombine(value) => {
+                let mut output: Vec<(String, String)> = self
+                    .comp_flag_options()
+                    .iter()
+                    .filter_map(|(x, y)| {
+                        if x.len() == 2 {
+                            Some((format!("{value}{}", &x[1..]), y.to_string()))
+                        } else {
+                            None
+                        }
+                    })
+                    .collect();
+                if output.len() == 1 {
+                    output.insert(0, (value.to_string(), String::new()));
+                }
+                output
+            }
             ArgComp::CommandOrPositional => {
                 let level = self.cmds.len() - 1;
                 let mut cmd = self.cmds[level].1;
@@ -275,6 +281,10 @@ impl<'a, 'b> Matcher<'a, 'b> {
         }
     }
 
+    pub fn has_dashdash(&self) -> bool {
+        !self.dashdash.is_empty()
+    }
+
     fn to_arg_values_base(&self) -> Vec<ArgcValue> {
         let mut output = vec![];
         let cmds_len = self.cmds.len();
@@ -537,8 +547,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
             }
             MatchError::DisplayVersion => {
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(self.cmds.len() - 1);
-                let output = cmd.render_version(&cmd_paths);
-                format!("{output}\n")
+                cmd.render_version(&cmd_paths)
             }
             MatchError::InvalidSubcommand => {
                 exit = 1;
@@ -664,9 +673,9 @@ For more information, try '--help'.
         for param in cmd.flag_option_params.iter() {
             let exist = args.contains(param.name.as_str());
             if !exist || param.multiple {
-                let describe = param.describe.clone();
+                let describe = param.describe_head();
                 for v in param.list_names() {
-                    output.push((v, describe.clone()))
+                    output.push((v, describe.to_string()))
                 }
             }
         }
@@ -751,9 +760,9 @@ fn comp_subcommands_positional(cmd: &Command, values: &[Vec<&str>]) -> Vec<(Stri
 fn comp_subcomands(cmd: &Command) -> Vec<(String, String)> {
     let mut output = vec![];
     for subcmd in cmd.subcommands.iter() {
-        let describe = subcmd.describe.clone();
+        let describe = subcmd.describe_head();
         for v in subcmd.list_names() {
-            output.push((v, describe.clone()))
+            output.push((v, describe.to_string()))
         }
     }
     output
@@ -766,7 +775,7 @@ fn comp_flag_option(param: &FlagOptionParam, index: usize) -> Vec<(String, Strin
         .map(|v| v.as_str())
         .unwrap_or_else(|| param.arg_value_names.last().unwrap());
     comp_param(
-        &param.describe,
+        param.describe_head(),
         value_name,
         &param.choices,
         &param.choices_fn,
@@ -777,7 +786,7 @@ fn comp_flag_option(param: &FlagOptionParam, index: usize) -> Vec<(String, Strin
 
 fn comp_positional(param: &PositionalParam) -> Vec<(String, String)> {
     comp_param(
-        &param.describe,
+        param.describe_head(),
         &param.arg_value_name,
         &param.choices,
         &param.choices_fn,
