@@ -1,7 +1,7 @@
 use assert_cmd::prelude::*;
 use std::process::Command;
 
-use crate::fixtures::{get_path_env_var, get_spec};
+use crate::fixtures::{get_path_env_var, locate_script};
 
 #[test]
 fn version() {
@@ -9,11 +9,11 @@ fn version() {
         .unwrap()
         .arg("--argc-version")
         .assert()
-        .stderr(predicates::str::contains(format!(
+        .stdout(predicates::str::contains(format!(
             "argc {}",
             env!("CARGO_PKG_VERSION")
         )))
-        .failure();
+        .success();
 }
 
 #[test]
@@ -22,22 +22,22 @@ fn help() {
         .unwrap()
         .arg("--argc-help")
         .assert()
-        .stderr(predicates::str::contains(env!("CARGO_PKG_DESCRIPTION")))
-        .failure();
+        .stdout(predicates::str::contains(env!("CARGO_PKG_DESCRIPTION")))
+        .success();
 }
 
 #[test]
 fn compgen() {
-    let (path, _) = get_spec();
+    let path = locate_script("args.sh");
     let path_env_var = get_path_env_var();
     Command::cargo_bin("argc")
         .unwrap()
         .arg("--argc-compgen")
         .arg("bash")
         .arg(path)
-        .arg("cmd_option_names --op11 ")
+        .arg("cmdj ")
         .env("PATH", path_env_var)
         .assert()
-        .stdout(predicates::str::contains("a1\na2\na3"))
+        .stdout(predicates::str::contains("abc\ndef\nghi"))
         .success();
 }
