@@ -161,7 +161,19 @@ _choice_fn() {
 }
 "###;
 
-    snapshot_compgen!(script, vec![" --oa ", " --ob ", " ", " v1 ",]);
+    snapshot_compgen!(script, vec![" --oa ", " --oa=", " --ob ", " ", " v1 ",]);
+}
+
+#[test]
+fn choice_multi() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+	echo -e "abc\ndef\nghi"
+}
+"###;
+
+    snapshot_compgen!(script, vec![" --oa ", " --oa="]);
 }
 
 #[test]
@@ -171,3 +183,52 @@ fn option_multi_vals() {
 "###;
     snapshot_compgen!(script, vec![" --oa ", " --oa bash ", " --oa bash cmd1 ",]);
 }
+
+#[test]
+fn multiline_doc() {
+    let script = r###"
+# @cmd cmd-line1
+# cmd-line2
+# @option --foo option-line1
+# option-line2
+# @arg bar bar-line1
+# bar-line2
+cmda() { :; }
+
+# @cmd line
+cmdb() { :; }
+"###;
+    snapshot_compgen!(script, vec![" ", "cmda ",]);
+}
+
+#[test]
+fn no_param() {
+    let script = r###"
+# @cmd
+cmd() { :; }
+"###;
+    snapshot_compgen!(script, vec!["cmd ",]);
+}
+
+#[test]
+fn special_arg_name() {
+    let script = r###"
+# @cmd
+# @arg arg
+cmda() { :; }
+
+# @cmd
+# @arg any
+cmdb() { :; }
+"###;
+    snapshot_compgen!(script, vec!["cmda ", "cmdb "]);
+}
+
+#[test]
+fn one_combine_shorts() {
+    let script = r###"
+# @flag -a
+# @flag -b
+"###;
+    snapshot_compgen!(script, vec![" -a"]);
+}
